@@ -12,7 +12,7 @@ use vars qw(
 ## Inheritance and Versioning ##
 
 @ISA     = qw( Exporter );
-$VERSION = '0.16';
+$VERSION = '0.17';
 
 ## Module Imports ##
 
@@ -530,7 +530,7 @@ B<Net::BGP::Notification>, B<Net::BGP::ASPath>, B<Net::BGP::Update>
 
 =head1 AUTHOR
 
-Stephen J. Scheck <code@neurosphere.com>
+Stephen J. Scheck <sscheck@cpan.org>
 
 =cut
 
